[![GitHub release](https://img.shields.io/github/release/genotoul-bioinfo/dgenies.svg)](https://GitHub.com/genotoul-bioinfo/dgenies/releases/) [![PyPI version](https://badge.fury.io/py/dgenies.svg)](https://badge.fury.io/py/dgenies) [![GitHub license](https://img.shields.io/github/license/genotoul-bioinfo/dgenies.svg)](https://github.com/genotoul-bioinfo/dgenies/blob/master/LICENSE.txt)
 [![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/) [![Documentation Status](https://readthedocs.org/projects/dgenies/badge/?version=latest)](http://dgenies.readthedocs.io/?badge=latest) [![Github all releases](https://img.shields.io/github/downloads/genotoul-bioinfo/dgenies/total.svg)](https://GitHub.com/genotoul-bioinfo/dgenies/releases/) [![Downloads](http://pepy.tech/badge/dgenies)](http://pepy.tech/project/dgenies)

D-Genies
--------

Dot plots are widely used to quickly compare sequence sets. They provide a synthetic similarity overview, highlighting repetitions, breaks and inversions. Different tools have been developed to easily generated genomic alignment dot plots, but they are often limited in the input sequence size. D-GENIES is a standalone and WEB application performing large genome alignments using [Minimap2](https://github.com/lh3/minimap2) or [MashMap v2.0](https://github.com/marbl/MashMap/) software packages and generating interactive dot plots. It enables users to sort query sequences along the reference, zoom in the plot and download several image, alignment or sequence files. D-GENIES is an easy to install open source software package (GPL) developed in Python and JavaScript.

How to use?
-----------

You can use the [demo instance hosted at genotoul](http://dgenies.toulouse.inrae.fr).

Or you can deploy your own instance with the help of [the installation documentation](http://dgenies.toulouse.inrae.fr/install).

Documentation
-------------

Full documentation, including code API, is available [here](https://dgenies.readthedocs.io/en/latest/index.html).

How to cite?
------------

Cabanettes F, Klopp C. (2018) D-GENIES: dot plot large genomes in an interactive, efficient and simple way. PeerJ 6:e4958 https://doi.org/10.7717/peerj.4958

Credits
-------

D-Genies is developed by the [Bioinfo team](http://bioinfo.genotoul.fr/index.php/about-us/) of the [Genotoul platform](http://www.genotoul.fr/) ([INRAE](http://www.inrae.fr/)).